Contributing to nc-time-axis

In proposing contributions to this project, you are agreeing to the following contribution terms.

Grant of Copyright Licence. Subject to the terms and conditions of this Agreement, You hereby grant to the Met Office and to recipients of software distributed by the Met Office a perpetual, worldwide, non-exclusive, royalty-free, irrevocable copyright licence to reproduce, prepare derivative works of, publicly display, publicly perform, sublicence, and distribute Your Contributions and such derivative works under the terms of the BSD 3-Clause licence: http://opensource.org/licenses/BSD-3-Clause

Intellectual Property Infringement. If any third party makes any claim against You or any other entity, alleging that your Contribution, or the Work to which you have contributed, infringes the intellectual property rights of that third party , then You shall inform the Met Office within 5 Working Days of such claim in order for the Met Office to take all appropriate action it deems necessary in relation to the claim.

You represent that you are legally entitled to grant the above licence. If your employer(s) has rights to intellectual property that you create that includes your Contributions, you represent that you have received permission to make Contributions on behalf of that employer, or that your employer has waived such rights for your Contributions to the Met Office.

You represent that each of Your Contributions is Your original creation and that you have not assigned or otherwise given up your interest in the Contribution to any third party. You represent that Your Contribution submissions include complete details of any third-party licence or other restriction (including, but not limited to, related patents and trademarks) of which you are personally aware and which are associated with any part of Your Contributions.

You (or Your employer(s)) agree to fully indemnify the Met Office in the event that either of the above representations are untrue.


Definitions:
"You" (or "Your") shall mean the copyright owner or legal entity authorised by the copyright
owner that is making this Agreement with the Met Office. For legal entities, the entity
making a Contribution and all other entities that control, are controlled by, or are under
common control with that entity are considered to be a single Contributor.

For the purposes of this definition, "control" means (i) the power, direct or indirect, to cause
the direction or management of such entity, whether by contract or otherwise, or (ii)
ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial
ownership of such entity.

"Contribution" shall mean any original work of authorship, including any modifications or
additions to an existing work, that is intentionally submitted by You to the Met Office for
inclusion in, or documentation of, any of the products owned or managed by the Met Office
(the "Work"). For the purposes of this definition, "submitted" means any form of electronic,
verbal, or written communication sent to the Met Office or its representatives, including but
not limited to communication on electronic mailing lists, source code control systems, and
issue tracking systems that are managed by, or on behalf of, the Met Office for the purpose
of discussing and improving the Work, but excluding communication that is conspicuously
marked or otherwise designated in writing by You as "Not a Contribution."


"Parties" shall mean The Met Office and You.

"Met Office" shall mean the Met Office, an Executive Agency of the Department of
Business, Innovation and Skills of the United Kingdom of Great Britain and Northern
Ireland ("BIS"), whose principal place of business is situated at FitzRoy Road, Exeter,
Devon EX1 3PB, United Kingdom, for an on behalf of BIS.

"Working Day" shall mean a day other than a Saturday, Sunday or public holiday in England
when banks in London are open for business.

"Data" shall have the same meaning as set out in the Data Protection Act 1998.
